"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MiTransportAdminMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class GroupImageChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupImageChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            CHANGED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupImageChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        CHANGED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupImageChanged.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.GroupImageChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class MessagePinned(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.MessagePinned._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            PINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 1
            UNPINNED: MiTransportAdminMessage.MessagePinned._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        PINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 1
        UNPINNED: MiTransportAdminMessage.MessagePinned.Action.ValueType  # 2

        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType
        def __init__(
            self,
            *,
            action: global___MiTransportAdminMessage.MessagePinned.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action"]) -> None: ...

    @typing.final
    class GroupMembershipAddModeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 1
            ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged._Mode.ValueType  # 2

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        ALL_MEMBERS: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 1
        ADMINS_ONLY: MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType  # 2

        MODE_FIELD_NUMBER: builtins.int
        mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType
        def __init__(
            self,
            *,
            mode: global___MiTransportAdminMessage.GroupMembershipAddModeChanged.Mode.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["mode", b"mode"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode"]) -> None: ...

    @typing.final
    class GroupAdminChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupAdminChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ADDED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupAdminChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        ADDED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupAdminChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupAdminChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class GroupParticipantChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ADDED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 1
            REMOVED: MiTransportAdminMessage.GroupParticipantChanged._Action.ValueType  # 2

        class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
        ADDED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 1
        REMOVED: MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType  # 2

        TARGETUSERID_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType
        @property
        def targetUserID(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            targetUserID: collections.abc.Iterable[builtins.str] | None = ...,
            action: global___MiTransportAdminMessage.GroupParticipantChanged.Action.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class DisappearingSettingChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        OLDDISAPPEARINGSETTINGDURATIONSECONDS_FIELD_NUMBER: builtins.int
        disappearingSettingDurationSeconds: builtins.int
        oldDisappearingSettingDurationSeconds: builtins.int
        def __init__(
            self,
            *,
            disappearingSettingDurationSeconds: builtins.int | None = ...,
            oldDisappearingSettingDurationSeconds: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["disappearingSettingDurationSeconds", b"disappearingSettingDurationSeconds", "oldDisappearingSettingDurationSeconds", b"oldDisappearingSettingDurationSeconds"]) -> None: ...

    @typing.final
    class IconChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THREADICON_FIELD_NUMBER: builtins.int
        threadIcon: builtins.str
        def __init__(
            self,
            *,
            threadIcon: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["threadIcon", b"threadIcon"]) -> None: ...

    @typing.final
    class LinkCta(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class UkOsaAdminText(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            INITIATORUSERID_FIELD_NUMBER: builtins.int
            initiatorUserID: builtins.str
            def __init__(
                self,
                *,
                initiatorUserID: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["initiatorUserID", b"initiatorUserID"]) -> None: ...

        UKOSAADMINTEXT_FIELD_NUMBER: builtins.int
        @property
        def ukOsaAdminText(self) -> global___MiTransportAdminMessage.LinkCta.UkOsaAdminText: ...
        def __init__(
            self,
            *,
            ukOsaAdminText: global___MiTransportAdminMessage.LinkCta.UkOsaAdminText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["content", b"content", "ukOsaAdminText", b"ukOsaAdminText"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["ukOsaAdminText"] | None: ...

    @typing.final
    class QuickReactionChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EMOJINAME_FIELD_NUMBER: builtins.int
        emojiName: builtins.str
        def __init__(
            self,
            *,
            emojiName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["emojiName", b"emojiName"]) -> None: ...

    @typing.final
    class GroupNameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUPNAME_FIELD_NUMBER: builtins.int
        groupName: builtins.str
        def __init__(
            self,
            *,
            groupName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["groupName", b"groupName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["groupName", b"groupName"]) -> None: ...

    @typing.final
    class NicknameChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TARGETUSERID_FIELD_NUMBER: builtins.int
        NICKNAME_FIELD_NUMBER: builtins.int
        targetUserID: builtins.str
        nickname: builtins.str
        def __init__(
            self,
            *,
            targetUserID: builtins.str | None = ...,
            nickname: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["nickname", b"nickname", "targetUserID", b"targetUserID"]) -> None: ...

    @typing.final
    class ChatThemeChanged(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        THEMENAME_FIELD_NUMBER: builtins.int
        THEMEEMOJI_FIELD_NUMBER: builtins.int
        THEMETYPE_FIELD_NUMBER: builtins.int
        themeName: builtins.str
        themeEmoji: builtins.str
        themeType: builtins.int
        def __init__(
            self,
            *,
            themeName: builtins.str | None = ...,
            themeEmoji: builtins.str | None = ...,
            themeType: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["themeEmoji", b"themeEmoji", "themeName", b"themeName", "themeType", b"themeType"]) -> None: ...

    CHATTHEMECHANGED_FIELD_NUMBER: builtins.int
    NICKNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPPARTICIPANTCHANGED_FIELD_NUMBER: builtins.int
    GROUPADMINCHANGED_FIELD_NUMBER: builtins.int
    GROUPNAMECHANGED_FIELD_NUMBER: builtins.int
    GROUPMEMBERSHIPADDMODECHANGED_FIELD_NUMBER: builtins.int
    MESSAGEPINNED_FIELD_NUMBER: builtins.int
    GROUPIMAGECHANGED_FIELD_NUMBER: builtins.int
    QUICKREACTIONCHANGED_FIELD_NUMBER: builtins.int
    LINKCTA_FIELD_NUMBER: builtins.int
    ICONCHANGED_FIELD_NUMBER: builtins.int
    DISAPPEARINGSETTINGCHANGED_FIELD_NUMBER: builtins.int
    @property
    def chatThemeChanged(self) -> global___MiTransportAdminMessage.ChatThemeChanged: ...
    @property
    def nicknameChanged(self) -> global___MiTransportAdminMessage.NicknameChanged: ...
    @property
    def groupParticipantChanged(self) -> global___MiTransportAdminMessage.GroupParticipantChanged: ...
    @property
    def groupAdminChanged(self) -> global___MiTransportAdminMessage.GroupAdminChanged: ...
    @property
    def groupNameChanged(self) -> global___MiTransportAdminMessage.GroupNameChanged: ...
    @property
    def groupMembershipAddModeChanged(self) -> global___MiTransportAdminMessage.GroupMembershipAddModeChanged: ...
    @property
    def messagePinned(self) -> global___MiTransportAdminMessage.MessagePinned: ...
    @property
    def groupImageChanged(self) -> global___MiTransportAdminMessage.GroupImageChanged: ...
    @property
    def quickReactionChanged(self) -> global___MiTransportAdminMessage.QuickReactionChanged: ...
    @property
    def linkCta(self) -> global___MiTransportAdminMessage.LinkCta: ...
    @property
    def iconChanged(self) -> global___MiTransportAdminMessage.IconChanged: ...
    @property
    def disappearingSettingChanged(self) -> global___MiTransportAdminMessage.DisappearingSettingChanged: ...
    def __init__(
        self,
        *,
        chatThemeChanged: global___MiTransportAdminMessage.ChatThemeChanged | None = ...,
        nicknameChanged: global___MiTransportAdminMessage.NicknameChanged | None = ...,
        groupParticipantChanged: global___MiTransportAdminMessage.GroupParticipantChanged | None = ...,
        groupAdminChanged: global___MiTransportAdminMessage.GroupAdminChanged | None = ...,
        groupNameChanged: global___MiTransportAdminMessage.GroupNameChanged | None = ...,
        groupMembershipAddModeChanged: global___MiTransportAdminMessage.GroupMembershipAddModeChanged | None = ...,
        messagePinned: global___MiTransportAdminMessage.MessagePinned | None = ...,
        groupImageChanged: global___MiTransportAdminMessage.GroupImageChanged | None = ...,
        quickReactionChanged: global___MiTransportAdminMessage.QuickReactionChanged | None = ...,
        linkCta: global___MiTransportAdminMessage.LinkCta | None = ...,
        iconChanged: global___MiTransportAdminMessage.IconChanged | None = ...,
        disappearingSettingChanged: global___MiTransportAdminMessage.DisappearingSettingChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chatThemeChanged", b"chatThemeChanged", "content", b"content", "disappearingSettingChanged", b"disappearingSettingChanged", "groupAdminChanged", b"groupAdminChanged", "groupImageChanged", b"groupImageChanged", "groupMembershipAddModeChanged", b"groupMembershipAddModeChanged", "groupNameChanged", b"groupNameChanged", "groupParticipantChanged", b"groupParticipantChanged", "iconChanged", b"iconChanged", "linkCta", b"linkCta", "messagePinned", b"messagePinned", "nicknameChanged", b"nicknameChanged", "quickReactionChanged", b"quickReactionChanged"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["chatThemeChanged", "nicknameChanged", "groupParticipantChanged", "groupAdminChanged", "groupNameChanged", "groupMembershipAddModeChanged", "messagePinned", "groupImageChanged", "quickReactionChanged", "linkCta", "iconChanged", "disappearingSettingChanged"] | None: ...

global___MiTransportAdminMessage = MiTransportAdminMessage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DeviceProps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PlatformType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PlatformTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeviceProps._PlatformType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: DeviceProps._PlatformType.ValueType  # 0
        CHROME: DeviceProps._PlatformType.ValueType  # 1
        FIREFOX: DeviceProps._PlatformType.ValueType  # 2
        IE: DeviceProps._PlatformType.ValueType  # 3
        OPERA: DeviceProps._PlatformType.ValueType  # 4
        SAFARI: DeviceProps._PlatformType.ValueType  # 5
        EDGE: DeviceProps._PlatformType.ValueType  # 6
        DESKTOP: DeviceProps._PlatformType.ValueType  # 7
        IPAD: DeviceProps._PlatformType.ValueType  # 8
        ANDROID_TABLET: DeviceProps._PlatformType.ValueType  # 9
        OHANA: DeviceProps._PlatformType.ValueType  # 10
        ALOHA: DeviceProps._PlatformType.ValueType  # 11
        CATALINA: DeviceProps._PlatformType.ValueType  # 12
        TCL_TV: DeviceProps._PlatformType.ValueType  # 13
        IOS_PHONE: DeviceProps._PlatformType.ValueType  # 14
        IOS_CATALYST: DeviceProps._PlatformType.ValueType  # 15
        ANDROID_PHONE: DeviceProps._PlatformType.ValueType  # 16
        ANDROID_AMBIGUOUS: DeviceProps._PlatformType.ValueType  # 17
        WEAR_OS: DeviceProps._PlatformType.ValueType  # 18
        AR_WRIST: DeviceProps._PlatformType.ValueType  # 19
        AR_DEVICE: DeviceProps._PlatformType.ValueType  # 20
        UWP: DeviceProps._PlatformType.ValueType  # 21
        VR: DeviceProps._PlatformType.ValueType  # 22
        CLOUD_API: DeviceProps._PlatformType.ValueType  # 23
        SMARTGLASSES: DeviceProps._PlatformType.ValueType  # 24

    class PlatformType(_PlatformType, metaclass=_PlatformTypeEnumTypeWrapper): ...
    UNKNOWN: DeviceProps.PlatformType.ValueType  # 0
    CHROME: DeviceProps.PlatformType.ValueType  # 1
    FIREFOX: DeviceProps.PlatformType.ValueType  # 2
    IE: DeviceProps.PlatformType.ValueType  # 3
    OPERA: DeviceProps.PlatformType.ValueType  # 4
    SAFARI: DeviceProps.PlatformType.ValueType  # 5
    EDGE: DeviceProps.PlatformType.ValueType  # 6
    DESKTOP: DeviceProps.PlatformType.ValueType  # 7
    IPAD: DeviceProps.PlatformType.ValueType  # 8
    ANDROID_TABLET: DeviceProps.PlatformType.ValueType  # 9
    OHANA: DeviceProps.PlatformType.ValueType  # 10
    ALOHA: DeviceProps.PlatformType.ValueType  # 11
    CATALINA: DeviceProps.PlatformType.ValueType  # 12
    TCL_TV: DeviceProps.PlatformType.ValueType  # 13
    IOS_PHONE: DeviceProps.PlatformType.ValueType  # 14
    IOS_CATALYST: DeviceProps.PlatformType.ValueType  # 15
    ANDROID_PHONE: DeviceProps.PlatformType.ValueType  # 16
    ANDROID_AMBIGUOUS: DeviceProps.PlatformType.ValueType  # 17
    WEAR_OS: DeviceProps.PlatformType.ValueType  # 18
    AR_WRIST: DeviceProps.PlatformType.ValueType  # 19
    AR_DEVICE: DeviceProps.PlatformType.ValueType  # 20
    UWP: DeviceProps.PlatformType.ValueType  # 21
    VR: DeviceProps.PlatformType.ValueType  # 22
    CLOUD_API: DeviceProps.PlatformType.ValueType  # 23
    SMARTGLASSES: DeviceProps.PlatformType.ValueType  # 24

    @typing.final
    class HistorySyncConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FULLSYNCDAYSLIMIT_FIELD_NUMBER: builtins.int
        FULLSYNCSIZEMBLIMIT_FIELD_NUMBER: builtins.int
        STORAGEQUOTAMB_FIELD_NUMBER: builtins.int
        INLINEINITIALPAYLOADINE2EEMSG_FIELD_NUMBER: builtins.int
        RECENTSYNCDAYSLIMIT_FIELD_NUMBER: builtins.int
        SUPPORTCALLLOGHISTORY_FIELD_NUMBER: builtins.int
        SUPPORTBOTUSERAGENTCHATHISTORY_FIELD_NUMBER: builtins.int
        SUPPORTCAGREACTIONSANDPOLLS_FIELD_NUMBER: builtins.int
        SUPPORTBIZHOSTEDMSG_FIELD_NUMBER: builtins.int
        SUPPORTRECENTSYNCCHUNKMESSAGECOUNTTUNING_FIELD_NUMBER: builtins.int
        SUPPORTHOSTEDGROUPMSG_FIELD_NUMBER: builtins.int
        SUPPORTFBIDBOTCHATHISTORY_FIELD_NUMBER: builtins.int
        SUPPORTADDONHISTORYSYNCMIGRATION_FIELD_NUMBER: builtins.int
        SUPPORTMESSAGEASSOCIATION_FIELD_NUMBER: builtins.int
        fullSyncDaysLimit: builtins.int
        fullSyncSizeMbLimit: builtins.int
        storageQuotaMb: builtins.int
        inlineInitialPayloadInE2EeMsg: builtins.bool
        recentSyncDaysLimit: builtins.int
        supportCallLogHistory: builtins.bool
        supportBotUserAgentChatHistory: builtins.bool
        supportCagReactionsAndPolls: builtins.bool
        supportBizHostedMsg: builtins.bool
        supportRecentSyncChunkMessageCountTuning: builtins.bool
        supportHostedGroupMsg: builtins.bool
        supportFbidBotChatHistory: builtins.bool
        supportAddOnHistorySyncMigration: builtins.bool
        supportMessageAssociation: builtins.bool
        def __init__(
            self,
            *,
            fullSyncDaysLimit: builtins.int | None = ...,
            fullSyncSizeMbLimit: builtins.int | None = ...,
            storageQuotaMb: builtins.int | None = ...,
            inlineInitialPayloadInE2EeMsg: builtins.bool | None = ...,
            recentSyncDaysLimit: builtins.int | None = ...,
            supportCallLogHistory: builtins.bool | None = ...,
            supportBotUserAgentChatHistory: builtins.bool | None = ...,
            supportCagReactionsAndPolls: builtins.bool | None = ...,
            supportBizHostedMsg: builtins.bool | None = ...,
            supportRecentSyncChunkMessageCountTuning: builtins.bool | None = ...,
            supportHostedGroupMsg: builtins.bool | None = ...,
            supportFbidBotChatHistory: builtins.bool | None = ...,
            supportAddOnHistorySyncMigration: builtins.bool | None = ...,
            supportMessageAssociation: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["fullSyncDaysLimit", b"fullSyncDaysLimit", "fullSyncSizeMbLimit", b"fullSyncSizeMbLimit", "inlineInitialPayloadInE2EeMsg", b"inlineInitialPayloadInE2EeMsg", "recentSyncDaysLimit", b"recentSyncDaysLimit", "storageQuotaMb", b"storageQuotaMb", "supportAddOnHistorySyncMigration", b"supportAddOnHistorySyncMigration", "supportBizHostedMsg", b"supportBizHostedMsg", "supportBotUserAgentChatHistory", b"supportBotUserAgentChatHistory", "supportCagReactionsAndPolls", b"supportCagReactionsAndPolls", "supportCallLogHistory", b"supportCallLogHistory", "supportFbidBotChatHistory", b"supportFbidBotChatHistory", "supportHostedGroupMsg", b"supportHostedGroupMsg", "supportMessageAssociation", b"supportMessageAssociation", "supportRecentSyncChunkMessageCountTuning", b"supportRecentSyncChunkMessageCountTuning"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["fullSyncDaysLimit", b"fullSyncDaysLimit", "fullSyncSizeMbLimit", b"fullSyncSizeMbLimit", "inlineInitialPayloadInE2EeMsg", b"inlineInitialPayloadInE2EeMsg", "recentSyncDaysLimit", b"recentSyncDaysLimit", "storageQuotaMb", b"storageQuotaMb", "supportAddOnHistorySyncMigration", b"supportAddOnHistorySyncMigration", "supportBizHostedMsg", b"supportBizHostedMsg", "supportBotUserAgentChatHistory", b"supportBotUserAgentChatHistory", "supportCagReactionsAndPolls", b"supportCagReactionsAndPolls", "supportCallLogHistory", b"supportCallLogHistory", "supportFbidBotChatHistory", b"supportFbidBotChatHistory", "supportHostedGroupMsg", b"supportHostedGroupMsg", "supportMessageAssociation", b"supportMessageAssociation", "supportRecentSyncChunkMessageCountTuning", b"supportRecentSyncChunkMessageCountTuning"]) -> None: ...

    @typing.final
    class AppVersion(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PRIMARY_FIELD_NUMBER: builtins.int
        SECONDARY_FIELD_NUMBER: builtins.int
        TERTIARY_FIELD_NUMBER: builtins.int
        QUATERNARY_FIELD_NUMBER: builtins.int
        QUINARY_FIELD_NUMBER: builtins.int
        primary: builtins.int
        secondary: builtins.int
        tertiary: builtins.int
        quaternary: builtins.int
        quinary: builtins.int
        def __init__(
            self,
            *,
            primary: builtins.int | None = ...,
            secondary: builtins.int | None = ...,
            tertiary: builtins.int | None = ...,
            quaternary: builtins.int | None = ...,
            quinary: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["primary", b"primary", "quaternary", b"quaternary", "quinary", b"quinary", "secondary", b"secondary", "tertiary", b"tertiary"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["primary", b"primary", "quaternary", b"quaternary", "quinary", b"quinary", "secondary", b"secondary", "tertiary", b"tertiary"]) -> None: ...

    OS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PLATFORMTYPE_FIELD_NUMBER: builtins.int
    REQUIREFULLSYNC_FIELD_NUMBER: builtins.int
    HISTORYSYNCCONFIG_FIELD_NUMBER: builtins.int
    os: builtins.str
    platformType: global___DeviceProps.PlatformType.ValueType
    requireFullSync: builtins.bool
    @property
    def version(self) -> global___DeviceProps.AppVersion: ...
    @property
    def historySyncConfig(self) -> global___DeviceProps.HistorySyncConfig: ...
    def __init__(
        self,
        *,
        os: builtins.str | None = ...,
        version: global___DeviceProps.AppVersion | None = ...,
        platformType: global___DeviceProps.PlatformType.ValueType | None = ...,
        requireFullSync: builtins.bool | None = ...,
        historySyncConfig: global___DeviceProps.HistorySyncConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["historySyncConfig", b"historySyncConfig", "os", b"os", "platformType", b"platformType", "requireFullSync", b"requireFullSync", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["historySyncConfig", b"historySyncConfig", "os", b"os", "platformType", b"platformType", "requireFullSync", b"requireFullSync", "version", b"version"]) -> None: ...

global___DeviceProps = DeviceProps

@typing.final
class CompanionEphemeralIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLICKEY_FIELD_NUMBER: builtins.int
    DEVICETYPE_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    publicKey: builtins.bytes
    deviceType: global___DeviceProps.PlatformType.ValueType
    ref: builtins.str
    def __init__(
        self,
        *,
        publicKey: builtins.bytes | None = ...,
        deviceType: global___DeviceProps.PlatformType.ValueType | None = ...,
        ref: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deviceType", b"deviceType", "publicKey", b"publicKey", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deviceType", b"deviceType", "publicKey", b"publicKey", "ref", b"ref"]) -> None: ...

global___CompanionEphemeralIdentity = CompanionEphemeralIdentity

@typing.final
class CompanionCommitment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    hash: builtins.bytes
    def __init__(
        self,
        *,
        hash: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hash", b"hash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hash", b"hash"]) -> None: ...

global___CompanionCommitment = CompanionCommitment

@typing.final
class ProloguePayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPANIONEPHEMERALIDENTITY_FIELD_NUMBER: builtins.int
    COMMITMENT_FIELD_NUMBER: builtins.int
    companionEphemeralIdentity: builtins.bytes
    @property
    def commitment(self) -> global___CompanionCommitment: ...
    def __init__(
        self,
        *,
        companionEphemeralIdentity: builtins.bytes | None = ...,
        commitment: global___CompanionCommitment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["commitment", b"commitment", "companionEphemeralIdentity", b"companionEphemeralIdentity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["commitment", b"commitment", "companionEphemeralIdentity", b"companionEphemeralIdentity"]) -> None: ...

global___ProloguePayload = ProloguePayload

@typing.final
class PrimaryEphemeralIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLICKEY_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    publicKey: builtins.bytes
    nonce: builtins.bytes
    def __init__(
        self,
        *,
        publicKey: builtins.bytes | None = ...,
        nonce: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["nonce", b"nonce", "publicKey", b"publicKey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["nonce", b"nonce", "publicKey", b"publicKey"]) -> None: ...

global___PrimaryEphemeralIdentity = PrimaryEphemeralIdentity

@typing.final
class PairingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPANIONPUBLICKEY_FIELD_NUMBER: builtins.int
    COMPANIONIDENTITYKEY_FIELD_NUMBER: builtins.int
    ADVSECRET_FIELD_NUMBER: builtins.int
    companionPublicKey: builtins.bytes
    companionIdentityKey: builtins.bytes
    advSecret: builtins.bytes
    def __init__(
        self,
        *,
        companionPublicKey: builtins.bytes | None = ...,
        companionIdentityKey: builtins.bytes | None = ...,
        advSecret: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advSecret", b"advSecret", "companionIdentityKey", b"companionIdentityKey", "companionPublicKey", b"companionPublicKey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advSecret", b"advSecret", "companionIdentityKey", b"companionIdentityKey", "companionPublicKey", b"companionPublicKey"]) -> None: ...

global___PairingRequest = PairingRequest

@typing.final
class EncryptedPairingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTEDPAYLOAD_FIELD_NUMBER: builtins.int
    IV_FIELD_NUMBER: builtins.int
    encryptedPayload: builtins.bytes
    IV: builtins.bytes
    def __init__(
        self,
        *,
        encryptedPayload: builtins.bytes | None = ...,
        IV: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["IV", b"IV", "encryptedPayload", b"encryptedPayload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["IV", b"IV", "encryptedPayload", b"encryptedPayload"]) -> None: ...

global___EncryptedPairingRequest = EncryptedPairingRequest

@typing.final
class ClientPairingProps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISCHATDBLIDMIGRATED_FIELD_NUMBER: builtins.int
    ISSYNCDPURELIDSESSION_FIELD_NUMBER: builtins.int
    isChatDbLidMigrated: builtins.bool
    isSyncdPureLidSession: builtins.bool
    def __init__(
        self,
        *,
        isChatDbLidMigrated: builtins.bool | None = ...,
        isSyncdPureLidSession: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["isChatDbLidMigrated", b"isChatDbLidMigrated", "isSyncdPureLidSession", b"isSyncdPureLidSession"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isChatDbLidMigrated", b"isChatDbLidMigrated", "isSyncdPureLidSession", b"isSyncdPureLidSession"]) -> None: ...

global___ClientPairingProps = ClientPairingProps



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClientPayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TrafficAnonymization:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TrafficAnonymizationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._TrafficAnonymization.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OFF: ClientPayload._TrafficAnonymization.ValueType  # 0
        STANDARD: ClientPayload._TrafficAnonymization.ValueType  # 1

    class TrafficAnonymization(_TrafficAnonymization, metaclass=_TrafficAnonymizationEnumTypeWrapper): ...
    OFF: ClientPayload.TrafficAnonymization.ValueType  # 0
    STANDARD: ClientPayload.TrafficAnonymization.ValueType  # 1

    class _AccountType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AccountTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._AccountType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT: ClientPayload._AccountType.ValueType  # 0
        GUEST: ClientPayload._AccountType.ValueType  # 1

    class AccountType(_AccountType, metaclass=_AccountTypeEnumTypeWrapper): ...
    DEFAULT: ClientPayload.AccountType.ValueType  # 0
    GUEST: ClientPayload.AccountType.ValueType  # 1

    class _Product:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProductEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._Product.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WHATSAPP: ClientPayload._Product.ValueType  # 0
        MESSENGER: ClientPayload._Product.ValueType  # 1
        INTEROP: ClientPayload._Product.ValueType  # 2
        INTEROP_MSGR: ClientPayload._Product.ValueType  # 3
        WHATSAPP_LID: ClientPayload._Product.ValueType  # 4

    class Product(_Product, metaclass=_ProductEnumTypeWrapper): ...
    WHATSAPP: ClientPayload.Product.ValueType  # 0
    MESSENGER: ClientPayload.Product.ValueType  # 1
    INTEROP: ClientPayload.Product.ValueType  # 2
    INTEROP_MSGR: ClientPayload.Product.ValueType  # 3
    WHATSAPP_LID: ClientPayload.Product.ValueType  # 4

    class _ConnectType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConnectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._ConnectType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CELLULAR_UNKNOWN: ClientPayload._ConnectType.ValueType  # 0
        WIFI_UNKNOWN: ClientPayload._ConnectType.ValueType  # 1
        CELLULAR_EDGE: ClientPayload._ConnectType.ValueType  # 100
        CELLULAR_IDEN: ClientPayload._ConnectType.ValueType  # 101
        CELLULAR_UMTS: ClientPayload._ConnectType.ValueType  # 102
        CELLULAR_EVDO: ClientPayload._ConnectType.ValueType  # 103
        CELLULAR_GPRS: ClientPayload._ConnectType.ValueType  # 104
        CELLULAR_HSDPA: ClientPayload._ConnectType.ValueType  # 105
        CELLULAR_HSUPA: ClientPayload._ConnectType.ValueType  # 106
        CELLULAR_HSPA: ClientPayload._ConnectType.ValueType  # 107
        CELLULAR_CDMA: ClientPayload._ConnectType.ValueType  # 108
        CELLULAR_1XRTT: ClientPayload._ConnectType.ValueType  # 109
        CELLULAR_EHRPD: ClientPayload._ConnectType.ValueType  # 110
        CELLULAR_LTE: ClientPayload._ConnectType.ValueType  # 111
        CELLULAR_HSPAP: ClientPayload._ConnectType.ValueType  # 112

    class ConnectType(_ConnectType, metaclass=_ConnectTypeEnumTypeWrapper): ...
    CELLULAR_UNKNOWN: ClientPayload.ConnectType.ValueType  # 0
    WIFI_UNKNOWN: ClientPayload.ConnectType.ValueType  # 1
    CELLULAR_EDGE: ClientPayload.ConnectType.ValueType  # 100
    CELLULAR_IDEN: ClientPayload.ConnectType.ValueType  # 101
    CELLULAR_UMTS: ClientPayload.ConnectType.ValueType  # 102
    CELLULAR_EVDO: ClientPayload.ConnectType.ValueType  # 103
    CELLULAR_GPRS: ClientPayload.ConnectType.ValueType  # 104
    CELLULAR_HSDPA: ClientPayload.ConnectType.ValueType  # 105
    CELLULAR_HSUPA: ClientPayload.ConnectType.ValueType  # 106
    CELLULAR_HSPA: ClientPayload.ConnectType.ValueType  # 107
    CELLULAR_CDMA: ClientPayload.ConnectType.ValueType  # 108
    CELLULAR_1XRTT: ClientPayload.ConnectType.ValueType  # 109
    CELLULAR_EHRPD: ClientPayload.ConnectType.ValueType  # 110
    CELLULAR_LTE: ClientPayload.ConnectType.ValueType  # 111
    CELLULAR_HSPAP: ClientPayload.ConnectType.ValueType  # 112

    class _ConnectReason:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConnectReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._ConnectReason.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PUSH: ClientPayload._ConnectReason.ValueType  # 0
        USER_ACTIVATED: ClientPayload._ConnectReason.ValueType  # 1
        SCHEDULED: ClientPayload._ConnectReason.ValueType  # 2
        ERROR_RECONNECT: ClientPayload._ConnectReason.ValueType  # 3
        NETWORK_SWITCH: ClientPayload._ConnectReason.ValueType  # 4
        PING_RECONNECT: ClientPayload._ConnectReason.ValueType  # 5
        UNKNOWN: ClientPayload._ConnectReason.ValueType  # 6

    class ConnectReason(_ConnectReason, metaclass=_ConnectReasonEnumTypeWrapper): ...
    PUSH: ClientPayload.ConnectReason.ValueType  # 0
    USER_ACTIVATED: ClientPayload.ConnectReason.ValueType  # 1
    SCHEDULED: ClientPayload.ConnectReason.ValueType  # 2
    ERROR_RECONNECT: ClientPayload.ConnectReason.ValueType  # 3
    NETWORK_SWITCH: ClientPayload.ConnectReason.ValueType  # 4
    PING_RECONNECT: ClientPayload.ConnectReason.ValueType  # 5
    UNKNOWN: ClientPayload.ConnectReason.ValueType  # 6

    class _IOSAppExtension:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _IOSAppExtensionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload._IOSAppExtension.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHARE_EXTENSION: ClientPayload._IOSAppExtension.ValueType  # 0
        SERVICE_EXTENSION: ClientPayload._IOSAppExtension.ValueType  # 1
        INTENTS_EXTENSION: ClientPayload._IOSAppExtension.ValueType  # 2

    class IOSAppExtension(_IOSAppExtension, metaclass=_IOSAppExtensionEnumTypeWrapper): ...
    SHARE_EXTENSION: ClientPayload.IOSAppExtension.ValueType  # 0
    SERVICE_EXTENSION: ClientPayload.IOSAppExtension.ValueType  # 1
    INTENTS_EXTENSION: ClientPayload.IOSAppExtension.ValueType  # 2

    @typing.final
    class DNSSource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _DNSResolutionMethod:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _DNSResolutionMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload.DNSSource._DNSResolutionMethod.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SYSTEM: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 0
            GOOGLE: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 1
            HARDCODED: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 2
            OVERRIDE: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 3
            FALLBACK: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 4
            MNS: ClientPayload.DNSSource._DNSResolutionMethod.ValueType  # 5

        class DNSResolutionMethod(_DNSResolutionMethod, metaclass=_DNSResolutionMethodEnumTypeWrapper): ...
        SYSTEM: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 0
        GOOGLE: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 1
        HARDCODED: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 2
        OVERRIDE: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 3
        FALLBACK: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 4
        MNS: ClientPayload.DNSSource.DNSResolutionMethod.ValueType  # 5

        DNSMETHOD_FIELD_NUMBER: builtins.int
        APPCACHED_FIELD_NUMBER: builtins.int
        dnsMethod: global___ClientPayload.DNSSource.DNSResolutionMethod.ValueType
        appCached: builtins.bool
        def __init__(
            self,
            *,
            dnsMethod: global___ClientPayload.DNSSource.DNSResolutionMethod.ValueType | None = ...,
            appCached: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["appCached", b"appCached", "dnsMethod", b"dnsMethod"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["appCached", b"appCached", "dnsMethod", b"dnsMethod"]) -> None: ...

    @typing.final
    class WebInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _WebSubPlatform:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _WebSubPlatformEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload.WebInfo._WebSubPlatform.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            WEB_BROWSER: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 0
            APP_STORE: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 1
            WIN_STORE: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 2
            DARWIN: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 3
            WIN32: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 4
            WIN_HYBRID: ClientPayload.WebInfo._WebSubPlatform.ValueType  # 5

        class WebSubPlatform(_WebSubPlatform, metaclass=_WebSubPlatformEnumTypeWrapper): ...
        WEB_BROWSER: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 0
        APP_STORE: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 1
        WIN_STORE: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 2
        DARWIN: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 3
        WIN32: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 4
        WIN_HYBRID: ClientPayload.WebInfo.WebSubPlatform.ValueType  # 5

        @typing.final
        class WebdPayload(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            USESPARTICIPANTINKEY_FIELD_NUMBER: builtins.int
            SUPPORTSSTARREDMESSAGES_FIELD_NUMBER: builtins.int
            SUPPORTSDOCUMENTMESSAGES_FIELD_NUMBER: builtins.int
            SUPPORTSURLMESSAGES_FIELD_NUMBER: builtins.int
            SUPPORTSMEDIARETRY_FIELD_NUMBER: builtins.int
            SUPPORTSE2EIMAGE_FIELD_NUMBER: builtins.int
            SUPPORTSE2EVIDEO_FIELD_NUMBER: builtins.int
            SUPPORTSE2EAUDIO_FIELD_NUMBER: builtins.int
            SUPPORTSE2EDOCUMENT_FIELD_NUMBER: builtins.int
            DOCUMENTTYPES_FIELD_NUMBER: builtins.int
            FEATURES_FIELD_NUMBER: builtins.int
            usesParticipantInKey: builtins.bool
            supportsStarredMessages: builtins.bool
            supportsDocumentMessages: builtins.bool
            supportsURLMessages: builtins.bool
            supportsMediaRetry: builtins.bool
            supportsE2EImage: builtins.bool
            supportsE2EVideo: builtins.bool
            supportsE2EAudio: builtins.bool
            supportsE2EDocument: builtins.bool
            documentTypes: builtins.str
            features: builtins.bytes
            def __init__(
                self,
                *,
                usesParticipantInKey: builtins.bool | None = ...,
                supportsStarredMessages: builtins.bool | None = ...,
                supportsDocumentMessages: builtins.bool | None = ...,
                supportsURLMessages: builtins.bool | None = ...,
                supportsMediaRetry: builtins.bool | None = ...,
                supportsE2EImage: builtins.bool | None = ...,
                supportsE2EVideo: builtins.bool | None = ...,
                supportsE2EAudio: builtins.bool | None = ...,
                supportsE2EDocument: builtins.bool | None = ...,
                documentTypes: builtins.str | None = ...,
                features: builtins.bytes | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["documentTypes", b"documentTypes", "features", b"features", "supportsDocumentMessages", b"supportsDocumentMessages", "supportsE2EAudio", b"supportsE2EAudio", "supportsE2EDocument", b"supportsE2EDocument", "supportsE2EImage", b"supportsE2EImage", "supportsE2EVideo", b"supportsE2EVideo", "supportsMediaRetry", b"supportsMediaRetry", "supportsStarredMessages", b"supportsStarredMessages", "supportsURLMessages", b"supportsURLMessages", "usesParticipantInKey", b"usesParticipantInKey"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["documentTypes", b"documentTypes", "features", b"features", "supportsDocumentMessages", b"supportsDocumentMessages", "supportsE2EAudio", b"supportsE2EAudio", "supportsE2EDocument", b"supportsE2EDocument", "supportsE2EImage", b"supportsE2EImage", "supportsE2EVideo", b"supportsE2EVideo", "supportsMediaRetry", b"supportsMediaRetry", "supportsStarredMessages", b"supportsStarredMessages", "supportsURLMessages", b"supportsURLMessages", "usesParticipantInKey", b"usesParticipantInKey"]) -> None: ...

        REFTOKEN_FIELD_NUMBER: builtins.int
        VERSION_FIELD_NUMBER: builtins.int
        WEBDPAYLOAD_FIELD_NUMBER: builtins.int
        WEBSUBPLATFORM_FIELD_NUMBER: builtins.int
        refToken: builtins.str
        version: builtins.str
        webSubPlatform: global___ClientPayload.WebInfo.WebSubPlatform.ValueType
        @property
        def webdPayload(self) -> global___ClientPayload.WebInfo.WebdPayload: ...
        def __init__(
            self,
            *,
            refToken: builtins.str | None = ...,
            version: builtins.str | None = ...,
            webdPayload: global___ClientPayload.WebInfo.WebdPayload | None = ...,
            webSubPlatform: global___ClientPayload.WebInfo.WebSubPlatform.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["refToken", b"refToken", "version", b"version", "webSubPlatform", b"webSubPlatform", "webdPayload", b"webdPayload"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["refToken", b"refToken", "version", b"version", "webSubPlatform", b"webSubPlatform", "webdPayload", b"webdPayload"]) -> None: ...

    @typing.final
    class UserAgent(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _DeviceType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _DeviceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload.UserAgent._DeviceType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            PHONE: ClientPayload.UserAgent._DeviceType.ValueType  # 0
            TABLET: ClientPayload.UserAgent._DeviceType.ValueType  # 1
            DESKTOP: ClientPayload.UserAgent._DeviceType.ValueType  # 2
            WEARABLE: ClientPayload.UserAgent._DeviceType.ValueType  # 3
            VR: ClientPayload.UserAgent._DeviceType.ValueType  # 4

        class DeviceType(_DeviceType, metaclass=_DeviceTypeEnumTypeWrapper): ...
        PHONE: ClientPayload.UserAgent.DeviceType.ValueType  # 0
        TABLET: ClientPayload.UserAgent.DeviceType.ValueType  # 1
        DESKTOP: ClientPayload.UserAgent.DeviceType.ValueType  # 2
        WEARABLE: ClientPayload.UserAgent.DeviceType.ValueType  # 3
        VR: ClientPayload.UserAgent.DeviceType.ValueType  # 4

        class _ReleaseChannel:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ReleaseChannelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload.UserAgent._ReleaseChannel.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            RELEASE: ClientPayload.UserAgent._ReleaseChannel.ValueType  # 0
            BETA: ClientPayload.UserAgent._ReleaseChannel.ValueType  # 1
            ALPHA: ClientPayload.UserAgent._ReleaseChannel.ValueType  # 2
            DEBUG: ClientPayload.UserAgent._ReleaseChannel.ValueType  # 3

        class ReleaseChannel(_ReleaseChannel, metaclass=_ReleaseChannelEnumTypeWrapper): ...
        RELEASE: ClientPayload.UserAgent.ReleaseChannel.ValueType  # 0
        BETA: ClientPayload.UserAgent.ReleaseChannel.ValueType  # 1
        ALPHA: ClientPayload.UserAgent.ReleaseChannel.ValueType  # 2
        DEBUG: ClientPayload.UserAgent.ReleaseChannel.ValueType  # 3

        class _Platform:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _PlatformEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClientPayload.UserAgent._Platform.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 0
            IOS: ClientPayload.UserAgent._Platform.ValueType  # 1
            WINDOWS_PHONE: ClientPayload.UserAgent._Platform.ValueType  # 2
            BLACKBERRY: ClientPayload.UserAgent._Platform.ValueType  # 3
            BLACKBERRYX: ClientPayload.UserAgent._Platform.ValueType  # 4
            S40: ClientPayload.UserAgent._Platform.ValueType  # 5
            S60: ClientPayload.UserAgent._Platform.ValueType  # 6
            PYTHON_CLIENT: ClientPayload.UserAgent._Platform.ValueType  # 7
            TIZEN: ClientPayload.UserAgent._Platform.ValueType  # 8
            ENTERPRISE: ClientPayload.UserAgent._Platform.ValueType  # 9
            SMB_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 10
            KAIOS: ClientPayload.UserAgent._Platform.ValueType  # 11
            SMB_IOS: ClientPayload.UserAgent._Platform.ValueType  # 12
            WINDOWS: ClientPayload.UserAgent._Platform.ValueType  # 13
            WEB: ClientPayload.UserAgent._Platform.ValueType  # 14
            PORTAL: ClientPayload.UserAgent._Platform.ValueType  # 15
            GREEN_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 16
            GREEN_IPHONE: ClientPayload.UserAgent._Platform.ValueType  # 17
            BLUE_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 18
            BLUE_IPHONE: ClientPayload.UserAgent._Platform.ValueType  # 19
            FBLITE_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 20
            MLITE_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 21
            IGLITE_ANDROID: ClientPayload.UserAgent._Platform.ValueType  # 22
            PAGE: ClientPayload.UserAgent._Platform.ValueType  # 23
            MACOS: ClientPayload.UserAgent._Platform.ValueType  # 24
            OCULUS_MSG: ClientPayload.UserAgent._Platform.ValueType  # 25
            OCULUS_CALL: ClientPayload.UserAgent._Platform.ValueType  # 26
            MILAN: ClientPayload.UserAgent._Platform.ValueType  # 27
            CAPI: ClientPayload.UserAgent._Platform.ValueType  # 28
            WEAROS: ClientPayload.UserAgent._Platform.ValueType  # 29
            ARDEVICE: ClientPayload.UserAgent._Platform.ValueType  # 30
            VRDEVICE: ClientPayload.UserAgent._Platform.ValueType  # 31
            BLUE_WEB: ClientPayload.UserAgent._Platform.ValueType  # 32
            IPAD: ClientPayload.UserAgent._Platform.ValueType  # 33
            TEST: ClientPayload.UserAgent._Platform.ValueType  # 34
            SMART_GLASSES: ClientPayload.UserAgent._Platform.ValueType  # 35

        class Platform(_Platform, metaclass=_PlatformEnumTypeWrapper): ...
        ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 0
        IOS: ClientPayload.UserAgent.Platform.ValueType  # 1
        WINDOWS_PHONE: ClientPayload.UserAgent.Platform.ValueType  # 2
        BLACKBERRY: ClientPayload.UserAgent.Platform.ValueType  # 3
        BLACKBERRYX: ClientPayload.UserAgent.Platform.ValueType  # 4
        S40: ClientPayload.UserAgent.Platform.ValueType  # 5
        S60: ClientPayload.UserAgent.Platform.ValueType  # 6
        PYTHON_CLIENT: ClientPayload.UserAgent.Platform.ValueType  # 7
        TIZEN: ClientPayload.UserAgent.Platform.ValueType  # 8
        ENTERPRISE: ClientPayload.UserAgent.Platform.ValueType  # 9
        SMB_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 10
        KAIOS: ClientPayload.UserAgent.Platform.ValueType  # 11
        SMB_IOS: ClientPayload.UserAgent.Platform.ValueType  # 12
        WINDOWS: ClientPayload.UserAgent.Platform.ValueType  # 13
        WEB: ClientPayload.UserAgent.Platform.ValueType  # 14
        PORTAL: ClientPayload.UserAgent.Platform.ValueType  # 15
        GREEN_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 16
        GREEN_IPHONE: ClientPayload.UserAgent.Platform.ValueType  # 17
        BLUE_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 18
        BLUE_IPHONE: ClientPayload.UserAgent.Platform.ValueType  # 19
        FBLITE_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 20
        MLITE_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 21
        IGLITE_ANDROID: ClientPayload.UserAgent.Platform.ValueType  # 22
        PAGE: ClientPayload.UserAgent.Platform.ValueType  # 23
        MACOS: ClientPayload.UserAgent.Platform.ValueType  # 24
        OCULUS_MSG: ClientPayload.UserAgent.Platform.ValueType  # 25
        OCULUS_CALL: ClientPayload.UserAgent.Platform.ValueType  # 26
        MILAN: ClientPayload.UserAgent.Platform.ValueType  # 27
        CAPI: ClientPayload.UserAgent.Platform.ValueType  # 28
        WEAROS: ClientPayload.UserAgent.Platform.ValueType  # 29
        ARDEVICE: ClientPayload.UserAgent.Platform.ValueType  # 30
        VRDEVICE: ClientPayload.UserAgent.Platform.ValueType  # 31
        BLUE_WEB: ClientPayload.UserAgent.Platform.ValueType  # 32
        IPAD: ClientPayload.UserAgent.Platform.ValueType  # 33
        TEST: ClientPayload.UserAgent.Platform.ValueType  # 34
        SMART_GLASSES: ClientPayload.UserAgent.Platform.ValueType  # 35

        @typing.final
        class AppVersion(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            PRIMARY_FIELD_NUMBER: builtins.int
            SECONDARY_FIELD_NUMBER: builtins.int
            TERTIARY_FIELD_NUMBER: builtins.int
            QUATERNARY_FIELD_NUMBER: builtins.int
            QUINARY_FIELD_NUMBER: builtins.int
            primary: builtins.int
            secondary: builtins.int
            tertiary: builtins.int
            quaternary: builtins.int
            quinary: builtins.int
            def __init__(
                self,
                *,
                primary: builtins.int | None = ...,
                secondary: builtins.int | None = ...,
                tertiary: builtins.int | None = ...,
                quaternary: builtins.int | None = ...,
                quinary: builtins.int | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["primary", b"primary", "quaternary", b"quaternary", "quinary", b"quinary", "secondary", b"secondary", "tertiary", b"tertiary"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["primary", b"primary", "quaternary", b"quaternary", "quinary", b"quinary", "secondary", b"secondary", "tertiary", b"tertiary"]) -> None: ...

        PLATFORM_FIELD_NUMBER: builtins.int
        APPVERSION_FIELD_NUMBER: builtins.int
        MCC_FIELD_NUMBER: builtins.int
        MNC_FIELD_NUMBER: builtins.int
        OSVERSION_FIELD_NUMBER: builtins.int
        MANUFACTURER_FIELD_NUMBER: builtins.int
        DEVICE_FIELD_NUMBER: builtins.int
        OSBUILDNUMBER_FIELD_NUMBER: builtins.int
        PHONEID_FIELD_NUMBER: builtins.int
        RELEASECHANNEL_FIELD_NUMBER: builtins.int
        LOCALELANGUAGEISO6391_FIELD_NUMBER: builtins.int
        LOCALECOUNTRYISO31661ALPHA2_FIELD_NUMBER: builtins.int
        DEVICEBOARD_FIELD_NUMBER: builtins.int
        DEVICEEXPID_FIELD_NUMBER: builtins.int
        DEVICETYPE_FIELD_NUMBER: builtins.int
        DEVICEMODELTYPE_FIELD_NUMBER: builtins.int
        platform: global___ClientPayload.UserAgent.Platform.ValueType
        mcc: builtins.str
        mnc: builtins.str
        osVersion: builtins.str
        manufacturer: builtins.str
        device: builtins.str
        osBuildNumber: builtins.str
        phoneID: builtins.str
        releaseChannel: global___ClientPayload.UserAgent.ReleaseChannel.ValueType
        localeLanguageIso6391: builtins.str
        localeCountryIso31661Alpha2: builtins.str
        deviceBoard: builtins.str
        deviceExpID: builtins.str
        deviceType: global___ClientPayload.UserAgent.DeviceType.ValueType
        deviceModelType: builtins.str
        @property
        def appVersion(self) -> global___ClientPayload.UserAgent.AppVersion: ...
        def __init__(
            self,
            *,
            platform: global___ClientPayload.UserAgent.Platform.ValueType | None = ...,
            appVersion: global___ClientPayload.UserAgent.AppVersion | None = ...,
            mcc: builtins.str | None = ...,
            mnc: builtins.str | None = ...,
            osVersion: builtins.str | None = ...,
            manufacturer: builtins.str | None = ...,
            device: builtins.str | None = ...,
            osBuildNumber: builtins.str | None = ...,
            phoneID: builtins.str | None = ...,
            releaseChannel: global___ClientPayload.UserAgent.ReleaseChannel.ValueType | None = ...,
            localeLanguageIso6391: builtins.str | None = ...,
            localeCountryIso31661Alpha2: builtins.str | None = ...,
            deviceBoard: builtins.str | None = ...,
            deviceExpID: builtins.str | None = ...,
            deviceType: global___ClientPayload.UserAgent.DeviceType.ValueType | None = ...,
            deviceModelType: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["appVersion", b"appVersion", "device", b"device", "deviceBoard", b"deviceBoard", "deviceExpID", b"deviceExpID", "deviceModelType", b"deviceModelType", "deviceType", b"deviceType", "localeCountryIso31661Alpha2", b"localeCountryIso31661Alpha2", "localeLanguageIso6391", b"localeLanguageIso6391", "manufacturer", b"manufacturer", "mcc", b"mcc", "mnc", b"mnc", "osBuildNumber", b"osBuildNumber", "osVersion", b"osVersion", "phoneID", b"phoneID", "platform", b"platform", "releaseChannel", b"releaseChannel"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["appVersion", b"appVersion", "device", b"device", "deviceBoard", b"deviceBoard", "deviceExpID", b"deviceExpID", "deviceModelType", b"deviceModelType", "deviceType", b"deviceType", "localeCountryIso31661Alpha2", b"localeCountryIso31661Alpha2", "localeLanguageIso6391", b"localeLanguageIso6391", "manufacturer", b"manufacturer", "mcc", b"mcc", "mnc", b"mnc", "osBuildNumber", b"osBuildNumber", "osVersion", b"osVersion", "phoneID", b"phoneID", "platform", b"platform", "releaseChannel", b"releaseChannel"]) -> None: ...

    @typing.final
    class InteropData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCOUNTID_FIELD_NUMBER: builtins.int
        TOKEN_FIELD_NUMBER: builtins.int
        ENABLEREADRECEIPTS_FIELD_NUMBER: builtins.int
        accountID: builtins.int
        token: builtins.bytes
        enableReadReceipts: builtins.bool
        def __init__(
            self,
            *,
            accountID: builtins.int | None = ...,
            token: builtins.bytes | None = ...,
            enableReadReceipts: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["accountID", b"accountID", "enableReadReceipts", b"enableReadReceipts", "token", b"token"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["accountID", b"accountID", "enableReadReceipts", b"enableReadReceipts", "token", b"token"]) -> None: ...

    @typing.final
    class DevicePairingRegistrationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EREGID_FIELD_NUMBER: builtins.int
        EKEYTYPE_FIELD_NUMBER: builtins.int
        EIDENT_FIELD_NUMBER: builtins.int
        ESKEYID_FIELD_NUMBER: builtins.int
        ESKEYVAL_FIELD_NUMBER: builtins.int
        ESKEYSIG_FIELD_NUMBER: builtins.int
        BUILDHASH_FIELD_NUMBER: builtins.int
        DEVICEPROPS_FIELD_NUMBER: builtins.int
        eRegid: builtins.bytes
        eKeytype: builtins.bytes
        eIdent: builtins.bytes
        eSkeyID: builtins.bytes
        eSkeyVal: builtins.bytes
        eSkeySig: builtins.bytes
        buildHash: builtins.bytes
        deviceProps: builtins.bytes
        def __init__(
            self,
            *,
            eRegid: builtins.bytes | None = ...,
            eKeytype: builtins.bytes | None = ...,
            eIdent: builtins.bytes | None = ...,
            eSkeyID: builtins.bytes | None = ...,
            eSkeyVal: builtins.bytes | None = ...,
            eSkeySig: builtins.bytes | None = ...,
            buildHash: builtins.bytes | None = ...,
            deviceProps: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["buildHash", b"buildHash", "deviceProps", b"deviceProps", "eIdent", b"eIdent", "eKeytype", b"eKeytype", "eRegid", b"eRegid", "eSkeyID", b"eSkeyID", "eSkeySig", b"eSkeySig", "eSkeyVal", b"eSkeyVal"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["buildHash", b"buildHash", "deviceProps", b"deviceProps", "eIdent", b"eIdent", "eKeytype", b"eKeytype", "eRegid", b"eRegid", "eSkeyID", b"eSkeyID", "eSkeySig", b"eSkeySig", "eSkeyVal", b"eSkeyVal"]) -> None: ...

    USERNAME_FIELD_NUMBER: builtins.int
    PASSIVE_FIELD_NUMBER: builtins.int
    USERAGENT_FIELD_NUMBER: builtins.int
    WEBINFO_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    SESSIONID_FIELD_NUMBER: builtins.int
    SHORTCONNECT_FIELD_NUMBER: builtins.int
    CONNECTTYPE_FIELD_NUMBER: builtins.int
    CONNECTREASON_FIELD_NUMBER: builtins.int
    SHARDS_FIELD_NUMBER: builtins.int
    DNSSOURCE_FIELD_NUMBER: builtins.int
    CONNECTATTEMPTCOUNT_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    DEVICEPAIRINGDATA_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    FBCAT_FIELD_NUMBER: builtins.int
    FBUSERAGENT_FIELD_NUMBER: builtins.int
    OC_FIELD_NUMBER: builtins.int
    LC_FIELD_NUMBER: builtins.int
    IOSAPPEXTENSION_FIELD_NUMBER: builtins.int
    FBAPPID_FIELD_NUMBER: builtins.int
    FBDEVICEID_FIELD_NUMBER: builtins.int
    PULL_FIELD_NUMBER: builtins.int
    PADDINGBYTES_FIELD_NUMBER: builtins.int
    YEARCLASS_FIELD_NUMBER: builtins.int
    MEMCLASS_FIELD_NUMBER: builtins.int
    INTEROPDATA_FIELD_NUMBER: builtins.int
    TRAFFICANONYMIZATION_FIELD_NUMBER: builtins.int
    LIDDBMIGRATED_FIELD_NUMBER: builtins.int
    ACCOUNTTYPE_FIELD_NUMBER: builtins.int
    username: builtins.int
    passive: builtins.bool
    pushName: builtins.str
    sessionID: builtins.int
    shortConnect: builtins.bool
    connectType: global___ClientPayload.ConnectType.ValueType
    connectReason: global___ClientPayload.ConnectReason.ValueType
    connectAttemptCount: builtins.int
    device: builtins.int
    product: global___ClientPayload.Product.ValueType
    fbCat: builtins.bytes
    fbUserAgent: builtins.bytes
    oc: builtins.bool
    lc: builtins.int
    iosAppExtension: global___ClientPayload.IOSAppExtension.ValueType
    fbAppID: builtins.int
    fbDeviceID: builtins.bytes
    pull: builtins.bool
    paddingBytes: builtins.bytes
    yearClass: builtins.int
    memClass: builtins.int
    trafficAnonymization: global___ClientPayload.TrafficAnonymization.ValueType
    lidDbMigrated: builtins.bool
    accountType: global___ClientPayload.AccountType.ValueType
    @property
    def userAgent(self) -> global___ClientPayload.UserAgent: ...
    @property
    def webInfo(self) -> global___ClientPayload.WebInfo: ...
    @property
    def shards(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def dnsSource(self) -> global___ClientPayload.DNSSource: ...
    @property
    def devicePairingData(self) -> global___ClientPayload.DevicePairingRegistrationData: ...
    @property
    def interopData(self) -> global___ClientPayload.InteropData: ...
    def __init__(
        self,
        *,
        username: builtins.int | None = ...,
        passive: builtins.bool | None = ...,
        userAgent: global___ClientPayload.UserAgent | None = ...,
        webInfo: global___ClientPayload.WebInfo | None = ...,
        pushName: builtins.str | None = ...,
        sessionID: builtins.int | None = ...,
        shortConnect: builtins.bool | None = ...,
        connectType: global___ClientPayload.ConnectType.ValueType | None = ...,
        connectReason: global___ClientPayload.ConnectReason.ValueType | None = ...,
        shards: collections.abc.Iterable[builtins.int] | None = ...,
        dnsSource: global___ClientPayload.DNSSource | None = ...,
        connectAttemptCount: builtins.int | None = ...,
        device: builtins.int | None = ...,
        devicePairingData: global___ClientPayload.DevicePairingRegistrationData | None = ...,
        product: global___ClientPayload.Product.ValueType | None = ...,
        fbCat: builtins.bytes | None = ...,
        fbUserAgent: builtins.bytes | None = ...,
        oc: builtins.bool | None = ...,
        lc: builtins.int | None = ...,
        iosAppExtension: global___ClientPayload.IOSAppExtension.ValueType | None = ...,
        fbAppID: builtins.int | None = ...,
        fbDeviceID: builtins.bytes | None = ...,
        pull: builtins.bool | None = ...,
        paddingBytes: builtins.bytes | None = ...,
        yearClass: builtins.int | None = ...,
        memClass: builtins.int | None = ...,
        interopData: global___ClientPayload.InteropData | None = ...,
        trafficAnonymization: global___ClientPayload.TrafficAnonymization.ValueType | None = ...,
        lidDbMigrated: builtins.bool | None = ...,
        accountType: global___ClientPayload.AccountType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["accountType", b"accountType", "connectAttemptCount", b"connectAttemptCount", "connectReason", b"connectReason", "connectType", b"connectType", "device", b"device", "devicePairingData", b"devicePairingData", "dnsSource", b"dnsSource", "fbAppID", b"fbAppID", "fbCat", b"fbCat", "fbDeviceID", b"fbDeviceID", "fbUserAgent", b"fbUserAgent", "interopData", b"interopData", "iosAppExtension", b"iosAppExtension", "lc", b"lc", "lidDbMigrated", b"lidDbMigrated", "memClass", b"memClass", "oc", b"oc", "paddingBytes", b"paddingBytes", "passive", b"passive", "product", b"product", "pull", b"pull", "pushName", b"pushName", "sessionID", b"sessionID", "shortConnect", b"shortConnect", "trafficAnonymization", b"trafficAnonymization", "userAgent", b"userAgent", "username", b"username", "webInfo", b"webInfo", "yearClass", b"yearClass"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accountType", b"accountType", "connectAttemptCount", b"connectAttemptCount", "connectReason", b"connectReason", "connectType", b"connectType", "device", b"device", "devicePairingData", b"devicePairingData", "dnsSource", b"dnsSource", "fbAppID", b"fbAppID", "fbCat", b"fbCat", "fbDeviceID", b"fbDeviceID", "fbUserAgent", b"fbUserAgent", "interopData", b"interopData", "iosAppExtension", b"iosAppExtension", "lc", b"lc", "lidDbMigrated", b"lidDbMigrated", "memClass", b"memClass", "oc", b"oc", "paddingBytes", b"paddingBytes", "passive", b"passive", "product", b"product", "pull", b"pull", "pushName", b"pushName", "sessionID", b"sessionID", "shards", b"shards", "shortConnect", b"shortConnect", "trafficAnonymization", b"trafficAnonymization", "userAgent", b"userAgent", "username", b"username", "webInfo", b"webInfo", "yearClass", b"yearClass"]) -> None: ...

global___ClientPayload = ClientPayload

@typing.final
class HandshakeMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ClientFinish(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STATIC_FIELD_NUMBER: builtins.int
        PAYLOAD_FIELD_NUMBER: builtins.int
        static: builtins.bytes
        payload: builtins.bytes
        def __init__(
            self,
            *,
            static: builtins.bytes | None = ...,
            payload: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["payload", b"payload", "static", b"static"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["payload", b"payload", "static", b"static"]) -> None: ...

    @typing.final
    class ServerHello(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EPHEMERAL_FIELD_NUMBER: builtins.int
        STATIC_FIELD_NUMBER: builtins.int
        PAYLOAD_FIELD_NUMBER: builtins.int
        ephemeral: builtins.bytes
        static: builtins.bytes
        payload: builtins.bytes
        def __init__(
            self,
            *,
            ephemeral: builtins.bytes | None = ...,
            static: builtins.bytes | None = ...,
            payload: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ephemeral", b"ephemeral", "payload", b"payload", "static", b"static"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ephemeral", b"ephemeral", "payload", b"payload", "static", b"static"]) -> None: ...

    @typing.final
    class ClientHello(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EPHEMERAL_FIELD_NUMBER: builtins.int
        STATIC_FIELD_NUMBER: builtins.int
        PAYLOAD_FIELD_NUMBER: builtins.int
        ephemeral: builtins.bytes
        static: builtins.bytes
        payload: builtins.bytes
        def __init__(
            self,
            *,
            ephemeral: builtins.bytes | None = ...,
            static: builtins.bytes | None = ...,
            payload: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["ephemeral", b"ephemeral", "payload", b"payload", "static", b"static"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ephemeral", b"ephemeral", "payload", b"payload", "static", b"static"]) -> None: ...

    CLIENTHELLO_FIELD_NUMBER: builtins.int
    SERVERHELLO_FIELD_NUMBER: builtins.int
    CLIENTFINISH_FIELD_NUMBER: builtins.int
    @property
    def clientHello(self) -> global___HandshakeMessage.ClientHello: ...
    @property
    def serverHello(self) -> global___HandshakeMessage.ServerHello: ...
    @property
    def clientFinish(self) -> global___HandshakeMessage.ClientFinish: ...
    def __init__(
        self,
        *,
        clientHello: global___HandshakeMessage.ClientHello | None = ...,
        serverHello: global___HandshakeMessage.ServerHello | None = ...,
        clientFinish: global___HandshakeMessage.ClientFinish | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clientFinish", b"clientFinish", "clientHello", b"clientHello", "serverHello", b"serverHello"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clientFinish", b"clientFinish", "clientHello", b"clientHello", "serverHello", b"serverHello"]) -> None: ...

global___HandshakeMessage = HandshakeMessage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waServerSync/WAServerSync.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waServerSync/WAServerSync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fwaServerSync/WAServerSync.proto\x12\x0cWAServerSync\"\xa0\x01\n\rSyncdMutation\x12=\n\toperation\x18\x01 \x01(\x0e\x32*.WAServerSync.SyncdMutation.SyncdOperation\x12)\n\x06record\x18\x02 \x01(\x0b\x32\x19.WAServerSync.SyncdRecord\"%\n\x0eSyncdOperation\x12\x07\n\x03SET\x10\x00\x12\n\n\x06REMOVE\x10\x01\"\x1f\n\x0cSyncdVersion\x12\x0f\n\x07version\x18\x01 \x01(\x04\"&\n\x08\x45xitCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x1a\n\nSyncdIndex\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\"\x1a\n\nSyncdValue\x12\x0c\n\x04\x62lob\x18\x01 \x01(\x0c\"\x13\n\x05KeyId\x12\n\n\x02ID\x18\x01 \x01(\x0c\"\x83\x01\n\x0bSyncdRecord\x12\'\n\x05index\x18\x01 \x01(\x0b\x32\x18.WAServerSync.SyncdIndex\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.WAServerSync.SyncdValue\x12\"\n\x05keyID\x18\x03 \x01(\x0b\x32\x13.WAServerSync.KeyId\"\x8f\x01\n\x15\x45xternalBlobReference\x12\x10\n\x08mediaKey\x18\x01 \x01(\x0c\x12\x12\n\ndirectPath\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\t\x12\x15\n\rfileSizeBytes\x18\x04 \x01(\x04\x12\x12\n\nfileSHA256\x18\x05 \x01(\x0c\x12\x15\n\rfileEncSHA256\x18\x06 \x01(\x0c\"\x99\x01\n\rSyncdSnapshot\x12+\n\x07version\x18\x01 \x01(\x0b\x32\x1a.WAServerSync.SyncdVersion\x12*\n\x07records\x18\x02 \x03(\x0b\x32\x19.WAServerSync.SyncdRecord\x12\x0b\n\x03mac\x18\x03 \x01(\x0c\x12\"\n\x05keyID\x18\x04 \x01(\x0b\x32\x13.WAServerSync.KeyId\"@\n\x0eSyncdMutations\x12.\n\tmutations\x18\x01 \x03(\x0b\x32\x1b.WAServerSync.SyncdMutation\"\xcc\x02\n\nSyncdPatch\x12+\n\x07version\x18\x01 \x01(\x0b\x32\x1a.WAServerSync.SyncdVersion\x12.\n\tmutations\x18\x02 \x03(\x0b\x32\x1b.WAServerSync.SyncdMutation\x12>\n\x11\x65xternalMutations\x18\x03 \x01(\x0b\x32#.WAServerSync.ExternalBlobReference\x12\x13\n\x0bsnapshotMAC\x18\x04 \x01(\x0c\x12\x10\n\x08patchMAC\x18\x05 \x01(\x0c\x12\"\n\x05keyID\x18\x06 \x01(\x0b\x32\x13.WAServerSync.KeyId\x12(\n\x08\x65xitCode\x18\x07 \x01(\x0b\x32\x16.WAServerSync.ExitCode\x12\x13\n\x0b\x64\x65viceIndex\x18\x08 \x01(\r\x12\x17\n\x0f\x63lientDebugData\x18\t \x01(\x0c\x42(Z&go.mau.fi/whatsmeow/proto/waServerSync')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waServerSync.WAServerSync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&go.mau.fi/whatsmeow/proto/waServerSync'
  _globals['_SYNCDMUTATION']._serialized_start=50
  _globals['_SYNCDMUTATION']._serialized_end=210
  _globals['_SYNCDMUTATION_SYNCDOPERATION']._serialized_start=173
  _globals['_SYNCDMUTATION_SYNCDOPERATION']._serialized_end=210
  _globals['_SYNCDVERSION']._serialized_start=212
  _globals['_SYNCDVERSION']._serialized_end=243
  _globals['_EXITCODE']._serialized_start=245
  _globals['_EXITCODE']._serialized_end=283
  _globals['_SYNCDINDEX']._serialized_start=285
  _globals['_SYNCDINDEX']._serialized_end=311
  _globals['_SYNCDVALUE']._serialized_start=313
  _globals['_SYNCDVALUE']._serialized_end=339
  _globals['_KEYID']._serialized_start=341
  _globals['_KEYID']._serialized_end=360
  _globals['_SYNCDRECORD']._serialized_start=363
  _globals['_SYNCDRECORD']._serialized_end=494
  _globals['_EXTERNALBLOBREFERENCE']._serialized_start=497
  _globals['_EXTERNALBLOBREFERENCE']._serialized_end=640
  _globals['_SYNCDSNAPSHOT']._serialized_start=643
  _globals['_SYNCDSNAPSHOT']._serialized_end=796
  _globals['_SYNCDMUTATIONS']._serialized_start=798
  _globals['_SYNCDMUTATIONS']._serialized_end=862
  _globals['_SYNCDPATCH']._serialized_start=865
  _globals['_SYNCDPATCH']._serialized_end=1197
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TransportEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Event(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class IcdcAlert(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Type:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TransportEvent.Event.IcdcAlert._Type.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                NONE: TransportEvent.Event.IcdcAlert._Type.ValueType  # 0
                DETECTED: TransportEvent.Event.IcdcAlert._Type.ValueType  # 1
                CLEARED: TransportEvent.Event.IcdcAlert._Type.ValueType  # 2

            class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
            NONE: TransportEvent.Event.IcdcAlert.Type.ValueType  # 0
            DETECTED: TransportEvent.Event.IcdcAlert.Type.ValueType  # 1
            CLEARED: TransportEvent.Event.IcdcAlert.Type.ValueType  # 2

            TYPE_FIELD_NUMBER: builtins.int
            type: global___TransportEvent.Event.IcdcAlert.Type.ValueType
            def __init__(
                self,
                *,
                type: global___TransportEvent.Event.IcdcAlert.Type.ValueType | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["type", b"type"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

        @typing.final
        class DeviceChange(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Type:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TransportEvent.Event.DeviceChange._Type.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                NONE: TransportEvent.Event.DeviceChange._Type.ValueType  # 0
                ADDED: TransportEvent.Event.DeviceChange._Type.ValueType  # 1
                REMOVED: TransportEvent.Event.DeviceChange._Type.ValueType  # 2
                REPLACED: TransportEvent.Event.DeviceChange._Type.ValueType  # 3

            class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
            NONE: TransportEvent.Event.DeviceChange.Type.ValueType  # 0
            ADDED: TransportEvent.Event.DeviceChange.Type.ValueType  # 1
            REMOVED: TransportEvent.Event.DeviceChange.Type.ValueType  # 2
            REPLACED: TransportEvent.Event.DeviceChange.Type.ValueType  # 3

            TYPE_FIELD_NUMBER: builtins.int
            DEVICENAME_FIELD_NUMBER: builtins.int
            DEVICEPLATFORM_FIELD_NUMBER: builtins.int
            DEVICEMODEL_FIELD_NUMBER: builtins.int
            type: global___TransportEvent.Event.DeviceChange.Type.ValueType
            deviceName: builtins.str
            devicePlatform: builtins.str
            deviceModel: builtins.str
            def __init__(
                self,
                *,
                type: global___TransportEvent.Event.DeviceChange.Type.ValueType | None = ...,
                deviceName: builtins.str | None = ...,
                devicePlatform: builtins.str | None = ...,
                deviceModel: builtins.str | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["deviceModel", b"deviceModel", "deviceName", b"deviceName", "devicePlatform", b"devicePlatform", "type", b"type"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["deviceModel", b"deviceModel", "deviceName", b"deviceName", "devicePlatform", b"devicePlatform", "type", b"type"]) -> None: ...

        DEVICECHANGE_FIELD_NUMBER: builtins.int
        ICDCALERT_FIELD_NUMBER: builtins.int
        @property
        def deviceChange(self) -> global___TransportEvent.Event.DeviceChange: ...
        @property
        def icdcAlert(self) -> global___TransportEvent.Event.IcdcAlert: ...
        def __init__(
            self,
            *,
            deviceChange: global___TransportEvent.Event.DeviceChange | None = ...,
            icdcAlert: global___TransportEvent.Event.IcdcAlert | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["deviceChange", b"deviceChange", "event", b"event", "icdcAlert", b"icdcAlert"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["deviceChange", b"deviceChange", "event", b"event", "icdcAlert", b"icdcAlert"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["event", b"event"]) -> typing.Literal["deviceChange", "icdcAlert"] | None: ...

    @typing.final
    class Placeholder(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TransportEvent.Placeholder._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DECRYPTION_FAILURE: TransportEvent.Placeholder._Type.ValueType  # 1
            UNAVAILABLE_MESSAGE: TransportEvent.Placeholder._Type.ValueType  # 2

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        DECRYPTION_FAILURE: TransportEvent.Placeholder.Type.ValueType  # 1
        UNAVAILABLE_MESSAGE: TransportEvent.Placeholder.Type.ValueType  # 2

        TYPE_FIELD_NUMBER: builtins.int
        type: global___TransportEvent.Placeholder.Type.ValueType
        def __init__(
            self,
            *,
            type: global___TransportEvent.Placeholder.Type.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

    PLACEHOLDER_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def placeholder(self) -> global___TransportEvent.Placeholder: ...
    @property
    def event(self) -> global___TransportEvent.Event: ...
    def __init__(
        self,
        *,
        placeholder: global___TransportEvent.Placeholder | None = ...,
        event: global___TransportEvent.Event | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "event", b"event", "placeholder", b"placeholder"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "event", b"event", "placeholder", b"placeholder"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["placeholder", "event"] | None: ...

global___TransportEvent = TransportEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waCommon.WACommon_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ConsumerApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTENT_FIELD_NUMBER: builtins.int
        APPLICATIONDATA_FIELD_NUMBER: builtins.int
        SIGNAL_FIELD_NUMBER: builtins.int
        SUBPROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def content(self) -> global___ConsumerApplication.Content: ...
        @property
        def applicationData(self) -> global___ConsumerApplication.ApplicationData: ...
        @property
        def signal(self) -> global___ConsumerApplication.Signal: ...
        @property
        def subProtocol(self) -> global___ConsumerApplication.SubProtocolPayload: ...
        def __init__(
            self,
            *,
            content: global___ConsumerApplication.Content | None = ...,
            applicationData: global___ConsumerApplication.ApplicationData | None = ...,
            signal: global___ConsumerApplication.Signal | None = ...,
            subProtocol: global___ConsumerApplication.SubProtocolPayload | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationData", b"applicationData", "content", b"content", "payload", b"payload", "signal", b"signal", "subProtocol", b"subProtocol"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["content", "applicationData", "signal", "subProtocol"] | None: ...

    @typing.final
    class SubProtocolPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FUTUREPROOF_FIELD_NUMBER: builtins.int
        futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType
        def __init__(
            self,
            *,
            futureProof: waCommon.WACommon_pb2.FutureProofBehavior.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["futureProof", b"futureProof"]) -> None: ...

    @typing.final
    class Metadata(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _SpecialTextSize:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SpecialTextSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConsumerApplication.Metadata._SpecialTextSize.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SMALL: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 1
            MEDIUM: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 2
            LARGE: ConsumerApplication.Metadata._SpecialTextSize.ValueType  # 3

        class SpecialTextSize(_SpecialTextSize, metaclass=_SpecialTextSizeEnumTypeWrapper): ...
        SMALL: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 1
        MEDIUM: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 2
        LARGE: ConsumerApplication.Metadata.SpecialTextSize.ValueType  # 3

        SPECIALTEXTSIZE_FIELD_NUMBER: builtins.int
        specialTextSize: global___ConsumerApplication.Metadata.SpecialTextSize.ValueType
        def __init__(
            self,
            *,
            specialTextSize: global___ConsumerApplication.Metadata.SpecialTextSize.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["specialTextSize", b"specialTextSize"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["specialTextSize", b"specialTextSize"]) -> None: ...

    @typing.final
    class Signal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class ApplicationData(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REVOKE_FIELD_NUMBER: builtins.int
        @property
        def revoke(self) -> global___ConsumerApplication.RevokeMessage: ...
        def __init__(
            self,
            *,
            revoke: global___ConsumerApplication.RevokeMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["applicationContent", b"applicationContent", "revoke", b"revoke"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["applicationContent", b"applicationContent", "revoke", b"revoke"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["applicationContent", b"applicationContent"]) -> typing.Literal["revoke"] | None: ...

    @typing.final
    class Content(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MESSAGETEXT_FIELD_NUMBER: builtins.int
        IMAGEMESSAGE_FIELD_NUMBER: builtins.int
        CONTACTMESSAGE_FIELD_NUMBER: builtins.int
        LOCATIONMESSAGE_FIELD_NUMBER: builtins.int
        EXTENDEDTEXTMESSAGE_FIELD_NUMBER: builtins.int
        STATUSTEXTMESSAGE_FIELD_NUMBER: builtins.int
        DOCUMENTMESSAGE_FIELD_NUMBER: builtins.int
        AUDIOMESSAGE_FIELD_NUMBER: builtins.int
        VIDEOMESSAGE_FIELD_NUMBER: builtins.int
        CONTACTSARRAYMESSAGE_FIELD_NUMBER: builtins.int
        LIVELOCATIONMESSAGE_FIELD_NUMBER: builtins.int
        STICKERMESSAGE_FIELD_NUMBER: builtins.int
        GROUPINVITEMESSAGE_FIELD_NUMBER: builtins.int
        VIEWONCEMESSAGE_FIELD_NUMBER: builtins.int
        REACTIONMESSAGE_FIELD_NUMBER: builtins.int
        POLLCREATIONMESSAGE_FIELD_NUMBER: builtins.int
        POLLUPDATEMESSAGE_FIELD_NUMBER: builtins.int
        EDITMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def messageText(self) -> waCommon.WACommon_pb2.MessageText: ...
        @property
        def imageMessage(self) -> global___ConsumerApplication.ImageMessage: ...
        @property
        def contactMessage(self) -> global___ConsumerApplication.ContactMessage: ...
        @property
        def locationMessage(self) -> global___ConsumerApplication.LocationMessage: ...
        @property
        def extendedTextMessage(self) -> global___ConsumerApplication.ExtendedTextMessage: ...
        @property
        def statusTextMessage(self) -> global___ConsumerApplication.StatusTextMesage: ...
        @property
        def documentMessage(self) -> global___ConsumerApplication.DocumentMessage: ...
        @property
        def audioMessage(self) -> global___ConsumerApplication.AudioMessage: ...
        @property
        def videoMessage(self) -> global___ConsumerApplication.VideoMessage: ...
        @property
        def contactsArrayMessage(self) -> global___ConsumerApplication.ContactsArrayMessage: ...
        @property
        def liveLocationMessage(self) -> global___ConsumerApplication.LiveLocationMessage: ...
        @property
        def stickerMessage(self) -> global___ConsumerApplication.StickerMessage: ...
        @property
        def groupInviteMessage(self) -> global___ConsumerApplication.GroupInviteMessage: ...
        @property
        def viewOnceMessage(self) -> global___ConsumerApplication.ViewOnceMessage: ...
        @property
        def reactionMessage(self) -> global___ConsumerApplication.ReactionMessage: ...
        @property
        def pollCreationMessage(self) -> global___ConsumerApplication.PollCreationMessage: ...
        @property
        def pollUpdateMessage(self) -> global___ConsumerApplication.PollUpdateMessage: ...
        @property
        def editMessage(self) -> global___ConsumerApplication.EditMessage: ...
        def __init__(
            self,
            *,
            messageText: waCommon.WACommon_pb2.MessageText | None = ...,
            imageMessage: global___ConsumerApplication.ImageMessage | None = ...,
            contactMessage: global___ConsumerApplication.ContactMessage | None = ...,
            locationMessage: global___ConsumerApplication.LocationMessage | None = ...,
            extendedTextMessage: global___ConsumerApplication.ExtendedTextMessage | None = ...,
            statusTextMessage: global___ConsumerApplication.StatusTextMesage | None = ...,
            documentMessage: global___ConsumerApplication.DocumentMessage | None = ...,
            audioMessage: global___ConsumerApplication.AudioMessage | None = ...,
            videoMessage: global___ConsumerApplication.VideoMessage | None = ...,
            contactsArrayMessage: global___ConsumerApplication.ContactsArrayMessage | None = ...,
            liveLocationMessage: global___ConsumerApplication.LiveLocationMessage | None = ...,
            stickerMessage: global___ConsumerApplication.StickerMessage | None = ...,
            groupInviteMessage: global___ConsumerApplication.GroupInviteMessage | None = ...,
            viewOnceMessage: global___ConsumerApplication.ViewOnceMessage | None = ...,
            reactionMessage: global___ConsumerApplication.ReactionMessage | None = ...,
            pollCreationMessage: global___ConsumerApplication.PollCreationMessage | None = ...,
            pollUpdateMessage: global___ConsumerApplication.PollUpdateMessage | None = ...,
            editMessage: global___ConsumerApplication.EditMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["audioMessage", b"audioMessage", "contactMessage", b"contactMessage", "contactsArrayMessage", b"contactsArrayMessage", "content", b"content", "documentMessage", b"documentMessage", "editMessage", b"editMessage", "extendedTextMessage", b"extendedTextMessage", "groupInviteMessage", b"groupInviteMessage", "imageMessage", b"imageMessage", "liveLocationMessage", b"liveLocationMessage", "locationMessage", b"locationMessage", "messageText", b"messageText", "pollCreationMessage", b"pollCreationMessage", "pollUpdateMessage", b"pollUpdateMessage", "reactionMessage", b"reactionMessage", "statusTextMessage", b"statusTextMessage", "stickerMessage", b"stickerMessage", "videoMessage", b"videoMessage", "viewOnceMessage", b"viewOnceMessage"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["audioMessage", b"audioMessage", "contactMessage", b"contactMessage", "contactsArrayMessage", b"contactsArrayMessage", "content", b"content", "documentMessage", b"documentMessage", "editMessage", b"editMessage", "extendedTextMessage", b"extendedTextMessage", "groupInviteMessage", b"groupInviteMessage", "imageMessage", b"imageMessage", "liveLocationMessage", b"liveLocationMessage", "locationMessage", b"locationMessage", "messageText", b"messageText", "pollCreationMessage", b"pollCreationMessage", "pollUpdateMessage", b"pollUpdateMessage", "reactionMessage", b"reactionMessage", "statusTextMessage", b"statusTextMessage", "stickerMessage", b"stickerMessage", "videoMessage", b"videoMessage", "viewOnceMessage", b"viewOnceMessage"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["messageText", "imageMessage", "contactMessage", "locationMessage", "extendedTextMessage", "statusTextMessage", "documentMessage", "audioMessage", "videoMessage", "contactsArrayMessage", "liveLocationMessage", "stickerMessage", "groupInviteMessage", "viewOnceMessage", "reactionMessage", "pollCreationMessage", "pollUpdateMessage", "editMessage"] | None: ...

    @typing.final
    class EditMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        TIMESTAMPMS_FIELD_NUMBER: builtins.int
        timestampMS: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        @property
        def message(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
            message: waCommon.WACommon_pb2.MessageText | None = ...,
            timestampMS: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key", "message", b"message", "timestampMS", b"timestampMS"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "message", b"message", "timestampMS", b"timestampMS"]) -> None: ...

    @typing.final
    class PollAddOptionMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POLLOPTION_FIELD_NUMBER: builtins.int
        @property
        def pollOption(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsumerApplication.Option]: ...
        def __init__(
            self,
            *,
            pollOption: collections.abc.Iterable[global___ConsumerApplication.Option] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["pollOption", b"pollOption"]) -> None: ...

    @typing.final
    class PollVoteMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SELECTEDOPTIONS_FIELD_NUMBER: builtins.int
        SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
        senderTimestampMS: builtins.int
        @property
        def selectedOptions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
        def __init__(
            self,
            *,
            selectedOptions: collections.abc.Iterable[builtins.bytes] | None = ...,
            senderTimestampMS: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["senderTimestampMS", b"senderTimestampMS"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["selectedOptions", b"selectedOptions", "senderTimestampMS", b"senderTimestampMS"]) -> None: ...

    @typing.final
    class PollEncValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENCPAYLOAD_FIELD_NUMBER: builtins.int
        ENCIV_FIELD_NUMBER: builtins.int
        encPayload: builtins.bytes
        encIV: builtins.bytes
        def __init__(
            self,
            *,
            encPayload: builtins.bytes | None = ...,
            encIV: builtins.bytes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["encIV", b"encIV", "encPayload", b"encPayload"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["encIV", b"encIV", "encPayload", b"encPayload"]) -> None: ...

    @typing.final
    class PollUpdateMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POLLCREATIONMESSAGEKEY_FIELD_NUMBER: builtins.int
        VOTE_FIELD_NUMBER: builtins.int
        ADDOPTION_FIELD_NUMBER: builtins.int
        @property
        def pollCreationMessageKey(self) -> waCommon.WACommon_pb2.MessageKey: ...
        @property
        def vote(self) -> global___ConsumerApplication.PollEncValue: ...
        @property
        def addOption(self) -> global___ConsumerApplication.PollEncValue: ...
        def __init__(
            self,
            *,
            pollCreationMessageKey: waCommon.WACommon_pb2.MessageKey | None = ...,
            vote: global___ConsumerApplication.PollEncValue | None = ...,
            addOption: global___ConsumerApplication.PollEncValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["addOption", b"addOption", "pollCreationMessageKey", b"pollCreationMessageKey", "vote", b"vote"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["addOption", b"addOption", "pollCreationMessageKey", b"pollCreationMessageKey", "vote", b"vote"]) -> None: ...

    @typing.final
    class PollCreationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENCKEY_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        OPTIONS_FIELD_NUMBER: builtins.int
        SELECTABLEOPTIONSCOUNT_FIELD_NUMBER: builtins.int
        encKey: builtins.bytes
        name: builtins.str
        selectableOptionsCount: builtins.int
        @property
        def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsumerApplication.Option]: ...
        def __init__(
            self,
            *,
            encKey: builtins.bytes | None = ...,
            name: builtins.str | None = ...,
            options: collections.abc.Iterable[global___ConsumerApplication.Option] | None = ...,
            selectableOptionsCount: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["encKey", b"encKey", "name", b"name", "selectableOptionsCount", b"selectableOptionsCount"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["encKey", b"encKey", "name", b"name", "options", b"options", "selectableOptionsCount", b"selectableOptionsCount"]) -> None: ...

    @typing.final
    class Option(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        OPTIONNAME_FIELD_NUMBER: builtins.int
        optionName: builtins.str
        def __init__(
            self,
            *,
            optionName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["optionName", b"optionName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["optionName", b"optionName"]) -> None: ...

    @typing.final
    class ReactionMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        TEXT_FIELD_NUMBER: builtins.int
        GROUPINGKEY_FIELD_NUMBER: builtins.int
        SENDERTIMESTAMPMS_FIELD_NUMBER: builtins.int
        REACTIONMETADATADATACLASSDATA_FIELD_NUMBER: builtins.int
        STYLE_FIELD_NUMBER: builtins.int
        text: builtins.str
        groupingKey: builtins.str
        senderTimestampMS: builtins.int
        reactionMetadataDataclassData: builtins.str
        style: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
            text: builtins.str | None = ...,
            groupingKey: builtins.str | None = ...,
            senderTimestampMS: builtins.int | None = ...,
            reactionMetadataDataclassData: builtins.str | None = ...,
            style: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["groupingKey", b"groupingKey", "key", b"key", "reactionMetadataDataclassData", b"reactionMetadataDataclassData", "senderTimestampMS", b"senderTimestampMS", "style", b"style", "text", b"text"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["groupingKey", b"groupingKey", "key", b"key", "reactionMetadataDataclassData", b"reactionMetadataDataclassData", "senderTimestampMS", b"senderTimestampMS", "style", b"style", "text", b"text"]) -> None: ...

    @typing.final
    class RevokeMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        @property
        def key(self) -> waCommon.WACommon_pb2.MessageKey: ...
        def __init__(
            self,
            *,
            key: waCommon.WACommon_pb2.MessageKey | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["key", b"key"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

    @typing.final
    class ViewOnceMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGEMESSAGE_FIELD_NUMBER: builtins.int
        VIDEOMESSAGE_FIELD_NUMBER: builtins.int
        @property
        def imageMessage(self) -> global___ConsumerApplication.ImageMessage: ...
        @property
        def videoMessage(self) -> global___ConsumerApplication.VideoMessage: ...
        def __init__(
            self,
            *,
            imageMessage: global___ConsumerApplication.ImageMessage | None = ...,
            videoMessage: global___ConsumerApplication.VideoMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["imageMessage", b"imageMessage", "videoMessage", b"videoMessage", "viewOnceContent", b"viewOnceContent"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["imageMessage", b"imageMessage", "videoMessage", b"videoMessage", "viewOnceContent", b"viewOnceContent"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["viewOnceContent", b"viewOnceContent"]) -> typing.Literal["imageMessage", "videoMessage"] | None: ...

    @typing.final
    class GroupInviteMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUPJID_FIELD_NUMBER: builtins.int
        INVITECODE_FIELD_NUMBER: builtins.int
        INVITEEXPIRATION_FIELD_NUMBER: builtins.int
        GROUPNAME_FIELD_NUMBER: builtins.int
        JPEGTHUMBNAIL_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        groupJID: builtins.str
        inviteCode: builtins.str
        inviteExpiration: builtins.int
        groupName: builtins.str
        JPEGThumbnail: builtins.bytes
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            groupJID: builtins.str | None = ...,
            inviteCode: builtins.str | None = ...,
            inviteExpiration: builtins.int | None = ...,
            groupName: builtins.str | None = ...,
            JPEGThumbnail: builtins.bytes | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["JPEGThumbnail", b"JPEGThumbnail", "caption", b"caption", "groupJID", b"groupJID", "groupName", b"groupName", "inviteCode", b"inviteCode", "inviteExpiration", b"inviteExpiration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["JPEGThumbnail", b"JPEGThumbnail", "caption", b"caption", "groupJID", b"groupJID", "groupName", b"groupName", "inviteCode", b"inviteCode", "inviteExpiration", b"inviteExpiration"]) -> None: ...

    @typing.final
    class LiveLocationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        ACCURACYINMETERS_FIELD_NUMBER: builtins.int
        SPEEDINMPS_FIELD_NUMBER: builtins.int
        DEGREESCLOCKWISEFROMMAGNETICNORTH_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        SEQUENCENUMBER_FIELD_NUMBER: builtins.int
        TIMEOFFSET_FIELD_NUMBER: builtins.int
        accuracyInMeters: builtins.int
        speedInMps: builtins.float
        degreesClockwiseFromMagneticNorth: builtins.int
        sequenceNumber: builtins.int
        timeOffset: builtins.int
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            accuracyInMeters: builtins.int | None = ...,
            speedInMps: builtins.float | None = ...,
            degreesClockwiseFromMagneticNorth: builtins.int | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
            sequenceNumber: builtins.int | None = ...,
            timeOffset: builtins.int | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["accuracyInMeters", b"accuracyInMeters", "caption", b"caption", "degreesClockwiseFromMagneticNorth", b"degreesClockwiseFromMagneticNorth", "location", b"location", "sequenceNumber", b"sequenceNumber", "speedInMps", b"speedInMps", "timeOffset", b"timeOffset"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["accuracyInMeters", b"accuracyInMeters", "caption", b"caption", "degreesClockwiseFromMagneticNorth", b"degreesClockwiseFromMagneticNorth", "location", b"location", "sequenceNumber", b"sequenceNumber", "speedInMps", b"speedInMps", "timeOffset", b"timeOffset"]) -> None: ...

    @typing.final
    class ContactsArrayMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DISPLAYNAME_FIELD_NUMBER: builtins.int
        CONTACTS_FIELD_NUMBER: builtins.int
        displayName: builtins.str
        @property
        def contacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsumerApplication.ContactMessage]: ...
        def __init__(
            self,
            *,
            displayName: builtins.str | None = ...,
            contacts: collections.abc.Iterable[global___ConsumerApplication.ContactMessage] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["displayName", b"displayName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contacts", b"contacts", "displayName", b"displayName"]) -> None: ...

    @typing.final
    class ContactMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CONTACT_FIELD_NUMBER: builtins.int
        @property
        def contact(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            contact: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["contact", b"contact"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contact", b"contact"]) -> None: ...

    @typing.final
    class StatusTextMesage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _FontType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _FontTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConsumerApplication.StatusTextMesage._FontType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SANS_SERIF: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 0
            SERIF: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 1
            NORICAN_REGULAR: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 2
            BRYNDAN_WRITE: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 3
            BEBASNEUE_REGULAR: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 4
            OSWALD_HEAVY: ConsumerApplication.StatusTextMesage._FontType.ValueType  # 5

        class FontType(_FontType, metaclass=_FontTypeEnumTypeWrapper): ...
        SANS_SERIF: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 0
        SERIF: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 1
        NORICAN_REGULAR: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 2
        BRYNDAN_WRITE: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 3
        BEBASNEUE_REGULAR: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 4
        OSWALD_HEAVY: ConsumerApplication.StatusTextMesage.FontType.ValueType  # 5

        TEXT_FIELD_NUMBER: builtins.int
        TEXTARGB_FIELD_NUMBER: builtins.int
        BACKGROUNDARGB_FIELD_NUMBER: builtins.int
        FONT_FIELD_NUMBER: builtins.int
        textArgb: builtins.int
        backgroundArgb: builtins.int
        font: global___ConsumerApplication.StatusTextMesage.FontType.ValueType
        @property
        def text(self) -> global___ConsumerApplication.ExtendedTextMessage: ...
        def __init__(
            self,
            *,
            text: global___ConsumerApplication.ExtendedTextMessage | None = ...,
            textArgb: builtins.int | None = ...,
            backgroundArgb: builtins.int | None = ...,
            font: global___ConsumerApplication.StatusTextMesage.FontType.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["backgroundArgb", b"backgroundArgb", "font", b"font", "text", b"text", "textArgb", b"textArgb"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["backgroundArgb", b"backgroundArgb", "font", b"font", "text", b"text", "textArgb", b"textArgb"]) -> None: ...

    @typing.final
    class ExtendedTextMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _PreviewType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _PreviewTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            NONE: ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType  # 0
            VIDEO: ConsumerApplication.ExtendedTextMessage._PreviewType.ValueType  # 1

        class PreviewType(_PreviewType, metaclass=_PreviewTypeEnumTypeWrapper): ...
        NONE: ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType  # 0
        VIDEO: ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType  # 1

        TEXT_FIELD_NUMBER: builtins.int
        MATCHEDTEXT_FIELD_NUMBER: builtins.int
        CANONICALURL_FIELD_NUMBER: builtins.int
        DESCRIPTION_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        THUMBNAIL_FIELD_NUMBER: builtins.int
        PREVIEWTYPE_FIELD_NUMBER: builtins.int
        matchedText: builtins.str
        canonicalURL: builtins.str
        description: builtins.str
        title: builtins.str
        previewType: global___ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType
        @property
        def text(self) -> waCommon.WACommon_pb2.MessageText: ...
        @property
        def thumbnail(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            text: waCommon.WACommon_pb2.MessageText | None = ...,
            matchedText: builtins.str | None = ...,
            canonicalURL: builtins.str | None = ...,
            description: builtins.str | None = ...,
            title: builtins.str | None = ...,
            thumbnail: waCommon.WACommon_pb2.SubProtocol | None = ...,
            previewType: global___ConsumerApplication.ExtendedTextMessage.PreviewType.ValueType | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["canonicalURL", b"canonicalURL", "description", b"description", "matchedText", b"matchedText", "previewType", b"previewType", "text", b"text", "thumbnail", b"thumbnail", "title", b"title"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["canonicalURL", b"canonicalURL", "description", b"description", "matchedText", b"matchedText", "previewType", b"previewType", "text", b"text", "thumbnail", b"thumbnail", "title", b"title"]) -> None: ...

    @typing.final
    class LocationMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        ADDRESS_FIELD_NUMBER: builtins.int
        address: builtins.str
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            address: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["address", b"address", "location", b"location"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["address", b"address", "location", b"location"]) -> None: ...

    @typing.final
    class StickerMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STICKER_FIELD_NUMBER: builtins.int
        @property
        def sticker(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            sticker: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["sticker", b"sticker"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["sticker", b"sticker"]) -> None: ...

    @typing.final
    class DocumentMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DOCUMENT_FIELD_NUMBER: builtins.int
        FILENAME_FIELD_NUMBER: builtins.int
        fileName: builtins.str
        @property
        def document(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            document: waCommon.WACommon_pb2.SubProtocol | None = ...,
            fileName: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["document", b"document", "fileName", b"fileName"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["document", b"document", "fileName", b"fileName"]) -> None: ...

    @typing.final
    class VideoMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VIDEO_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        @property
        def video(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            video: waCommon.WACommon_pb2.SubProtocol | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["caption", b"caption", "video", b"video"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["caption", b"caption", "video", b"video"]) -> None: ...

    @typing.final
    class AudioMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AUDIO_FIELD_NUMBER: builtins.int
        PTT_FIELD_NUMBER: builtins.int
        PTT: builtins.bool
        @property
        def audio(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            audio: waCommon.WACommon_pb2.SubProtocol | None = ...,
            PTT: builtins.bool | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["PTT", b"PTT", "audio", b"audio"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["PTT", b"PTT", "audio", b"audio"]) -> None: ...

    @typing.final
    class ImageMessage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGE_FIELD_NUMBER: builtins.int
        CAPTION_FIELD_NUMBER: builtins.int
        @property
        def image(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        @property
        def caption(self) -> waCommon.WACommon_pb2.MessageText: ...
        def __init__(
            self,
            *,
            image: waCommon.WACommon_pb2.SubProtocol | None = ...,
            caption: waCommon.WACommon_pb2.MessageText | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["caption", b"caption", "image", b"image"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["caption", b"caption", "image", b"image"]) -> None: ...

    @typing.final
    class InteractiveAnnotation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOCATION_FIELD_NUMBER: builtins.int
        POLYGONVERTICES_FIELD_NUMBER: builtins.int
        @property
        def location(self) -> global___ConsumerApplication.Location: ...
        @property
        def polygonVertices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsumerApplication.Point]: ...
        def __init__(
            self,
            *,
            location: global___ConsumerApplication.Location | None = ...,
            polygonVertices: collections.abc.Iterable[global___ConsumerApplication.Point] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "location", b"location"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "location", b"location", "polygonVertices", b"polygonVertices"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["location"] | None: ...

    @typing.final
    class Point(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        X_FIELD_NUMBER: builtins.int
        Y_FIELD_NUMBER: builtins.int
        x: builtins.float
        y: builtins.float
        def __init__(
            self,
            *,
            x: builtins.float | None = ...,
            y: builtins.float | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["x", b"x", "y", b"y"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["x", b"x", "y", b"y"]) -> None: ...

    @typing.final
    class Location(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DEGREESLATITUDE_FIELD_NUMBER: builtins.int
        DEGREESLONGITUDE_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        degreesLatitude: builtins.float
        degreesLongitude: builtins.float
        name: builtins.str
        def __init__(
            self,
            *,
            degreesLatitude: builtins.float | None = ...,
            degreesLongitude: builtins.float | None = ...,
            name: builtins.str | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["degreesLatitude", b"degreesLatitude", "degreesLongitude", b"degreesLongitude", "name", b"name"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["degreesLatitude", b"degreesLatitude", "degreesLongitude", b"degreesLongitude", "name", b"name"]) -> None: ...

    @typing.final
    class MediaPayload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROTOCOL_FIELD_NUMBER: builtins.int
        @property
        def protocol(self) -> waCommon.WACommon_pb2.SubProtocol: ...
        def __init__(
            self,
            *,
            protocol: waCommon.WACommon_pb2.SubProtocol | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["protocol", b"protocol"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["protocol", b"protocol"]) -> None: ...

    PAYLOAD_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def payload(self) -> global___ConsumerApplication.Payload: ...
    @property
    def metadata(self) -> global___ConsumerApplication.Metadata: ...
    def __init__(
        self,
        *,
        payload: global___ConsumerApplication.Payload | None = ...,
        metadata: global___ConsumerApplication.Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "payload", b"payload"]) -> None: ...

global___ConsumerApplication = ConsumerApplication
